@@ -30,13 +30,12 @@ sub init {
     $self->set_color( $self->{'init'} );
 }
 
-sub get_nr { $_[0]->{'nr'} }
-
 sub set_color {
     my ( $self, $color ) = @_;
     return unless ref $color eq 'HASH' and exists $color->{'red'} and exists $color->{'green'} and exists $color->{'blue'};
     $self->{$_} = $color->{$_} for qw/red green blue/;
     $self->Refresh;
+
 }
 
 sub get_color {
@@ -48,5 +47,13 @@ sub get_color {
     }
 }
 
+sub get_nr { $_[0]->{'nr'} }
+
+sub SetCallBack {
+    my ( $self, $code) = @_;
+    return unless ref $code eq 'CODE';
+    $self->{'callback'} = $code;
+}
 
 1;
+
